==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/KeystoneIdentityProviderBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class KeystoneIdentityProviderBuilder extends io.fabric8.openshift.api.model.KeystoneIdentityProviderFluentImpl<io.fabric8.openshift.api.model.KeystoneIdentityProviderBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.KeystoneIdentityProvider,io.fabric8.openshift.api.model.KeystoneIdentityProviderBuilder>{
  public KeystoneIdentityProviderBuilder() {
    this(false);
  }
  public KeystoneIdentityProviderBuilder(java.lang.Boolean validationEnabled) {
    this(new KeystoneIdentityProvider(), validationEnabled);
  }
  public KeystoneIdentityProviderBuilder(io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent<?> fluent) {
    this(fluent, false);
  }
  public KeystoneIdentityProviderBuilder(io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new KeystoneIdentityProvider(), validationEnabled);
  }
  public KeystoneIdentityProviderBuilder(io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent<?> fluent,io.fabric8.openshift.api.model.KeystoneIdentityProvider instance) {
    this(fluent, instance, false);
  }
  public KeystoneIdentityProviderBuilder(io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent<?> fluent,io.fabric8.openshift.api.model.KeystoneIdentityProvider instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withCa(instance.getCa()); 
    fluent.withDomainName(instance.getDomainName()); 
    fluent.withTlsClientCert(instance.getTlsClientCert()); 
    fluent.withTlsClientKey(instance.getTlsClientKey()); 
    fluent.withUrl(instance.getUrl()); 
    this.validationEnabled = validationEnabled; 
  }
  public KeystoneIdentityProviderBuilder(io.fabric8.openshift.api.model.KeystoneIdentityProvider instance) {
    this(instance,false);
  }
  public KeystoneIdentityProviderBuilder(io.fabric8.openshift.api.model.KeystoneIdentityProvider instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withCa(instance.getCa()); 
    this.withDomainName(instance.getDomainName()); 
    this.withTlsClientCert(instance.getTlsClientCert()); 
    this.withTlsClientKey(instance.getTlsClientKey()); 
    this.withUrl(instance.getUrl()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.KeystoneIdentityProvider build() {
    KeystoneIdentityProvider buildable = new KeystoneIdentityProvider(fluent.getCa(),fluent.getDomainName(),fluent.getTlsClientCert(),fluent.getTlsClientKey(),fluent.getUrl());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    KeystoneIdentityProviderBuilder that = (KeystoneIdentityProviderBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/KeystoneIdentityProviderBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class KeystoneIdentityProviderBuilder extends io.fabric8.openshift.api.model.KeystoneIdentityProviderFluentImpl<io.fabric8.openshift.api.model.KeystoneIdentityProviderBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.KeystoneIdentityProvider,io.fabric8.openshift.api.model.KeystoneIdentityProviderBuilder>{
  public KeystoneIdentityProviderBuilder() {
    this(false);
  }
  public KeystoneIdentityProviderBuilder(java.lang.Boolean validationEnabled) {
    this(new KeystoneIdentityProvider(), validationEnabled);
  }
  public KeystoneIdentityProviderBuilder(io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent<?> fluent) {
    this(fluent, false);
  }
  public KeystoneIdentityProviderBuilder(io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new KeystoneIdentityProvider(), validationEnabled);
  }
  public KeystoneIdentityProviderBuilder(io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent<?> fluent,io.fabric8.openshift.api.model.KeystoneIdentityProvider instance) {
    this(fluent, instance, false);
  }
  public KeystoneIdentityProviderBuilder(io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent<?> fluent,io.fabric8.openshift.api.model.KeystoneIdentityProvider instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withCa(instance.getCa()); 
    fluent.withDomainName(instance.getDomainName()); 
    fluent.withTlsClientCert(instance.getTlsClientCert()); 
    fluent.withTlsClientKey(instance.getTlsClientKey()); 
    fluent.withUrl(instance.getUrl()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public KeystoneIdentityProviderBuilder(io.fabric8.openshift.api.model.KeystoneIdentityProvider instance) {
    this(instance,false);
  }
  public KeystoneIdentityProviderBuilder(io.fabric8.openshift.api.model.KeystoneIdentityProvider instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withCa(instance.getCa()); 
    this.withDomainName(instance.getDomainName()); 
    this.withTlsClientCert(instance.getTlsClientCert()); 
    this.withTlsClientKey(instance.getTlsClientKey()); 
    this.withUrl(instance.getUrl()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.KeystoneIdentityProvider build() {
    KeystoneIdentityProvider buildable = new KeystoneIdentityProvider(fluent.getCa(),fluent.getDomainName(),fluent.getTlsClientCert(),fluent.getTlsClientKey(),fluent.getUrl());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    KeystoneIdentityProviderBuilder that = (KeystoneIdentityProviderBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
